Crate kpal_gpio_cdev

Crate kpal_gpio_cdev 

KPAL plugin to control the output of a single GPIO pin using the GPIO char device.

Functions

kpal_library_init
Initializes the library.
kpal_plugin_new
Returns a new Plugin instance containing the plugin data and the function vtable.